@@ -99,6 +99,9 @@ class bfit(object):
         Data Fields:
             asym_dict_keys: asym calc and draw types
             data:           dict of fitdata objects for drawing/fitting, keyed by run #
+            deadtime:       float, value of deadtime in s or scaling for local calcs
+            deadtime_switch:BooleanVar, if true, use deadtime correction
+            deadtime_global:BooleanVar, if true, deadtime value is dt, else is scaling
             draw_style:     StringVar, draw window types # stack, redraw, new
             draw_components:list of titles for labels, options to export, draw.
             draw_fit:       BooleanVar, if true draw fits after fitting
@@ -137,7 +140,6 @@ class bfit(object):
     norm_alph_diff_time = 0.1   # number of seconds to take average over when 
                                 # normalizing alpha diffusion runs
     legend_max_draw = 8 # max number of items to draw before removing the legend
-    deadtime_1f = 0        # deadtime in s, for counter corrections in 1f/1w/1n modes
     
     # track settings for use_nbm
     use_nbm_settings = {'default':False,
@@ -431,9 +433,14 @@ class bfit(object):
         self.nbm_dict[''].set(False)
         self.nbm_dict['1n'].set(True)
         
-        # deadtime slr
-        self.deadtime_slr = BooleanVar()
-        self.deadtime_slr.set(False)
+        # deadtime switches
+        self.deadtime_switch = BooleanVar()
+        self.deadtime_switch.set(False)
+        self.deadtime_global = BooleanVar()
+        self.deadtime_global.set(True)
+        self.deadtime = 0 # deadtime in s, or neg asymmetry scaling for deadtime 
+                          # calculations, depending on the value of self.global_deadtime
+    
         
         # Menu bar options ----------------------------------------------------
         root.option_add('*tearOff', FALSE)
@@ -462,8 +469,6 @@ class bfit(object):
         
         # Settings cascade commands
         menu_settings.add_cascade(menu=menu_settings_dir, label='Data directory')
-        menu_settings.add_command(label='Deadtime correction', 
-                command=self.set_deadtime)
         menu_settings.add_command(label='Drawing style', 
                 command=self.set_draw_style)
         menu_settings.add_command(label='Histograms', 
@@ -516,6 +521,8 @@ class bfit(object):
         # calculate
         menu_calculate = Menu(menubar, title='Calculate')
         menubar.add_cascade(menu=menu_calculate, label='Calculate')
+        menu_calculate.add_command(label='Deadtime correction', 
+                command=self.set_deadtime)
         menu_calculate.add_command(label='NQR B0', command=calculator_nqr_B0)
         menu_calculate.add_command(label='NMR B1', command=calculator_nmr_B1)
         menu_calculate.add_command(label='NMR B1 Attenuation', command=calculator_nmr_atten)
@@ -558,8 +565,6 @@ class bfit(object):
         menu_draw.add_separator()
         menu_draw.add_checkbutton(label="Use NBM in asymmetry", \
                 variable=self.nbm_dict[''], selectcolor=colors.selected)        
-        menu_draw.add_checkbutton(label="Use SLR deadtime correction", \
-                variable=self.deadtime_slr, selectcolor=colors.selected)        
         
         # Fitting minimizers
         menu_mini = Menu(menubar, title='Minimizer')
@@ -1605,7 +1610,7 @@ class bfit(object):
                                     probe_species = self.probe_species.get())
         self.fit_files.fit_routine_label['text'] = self.fit_files.fitter.__name__
         self.fit_files.populate()
-        self.logger.info('Success.')
+        self.logger.debug('Success.')
         
     # ======================================================================= #
     def set_fit_routine_with_popup(self):
